==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QNativeGestureEvent_shell.h <==
#ifndef QNATIVEGESTUREEVENT_SHELL_H
#define QNATIVEGESTUREEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QNativeGestureEvent_shell : public QNativeGestureEvent, public QtJambiShellInterface
{
public:
    QNativeGestureEvent_shell(const QNativeGestureEvent& arg__1);
    QNativeGestureEvent_shell(Qt::NativeGestureType type0, const QPointingDevice* dev1, const QPointF& localPos2, const QPointF& scenePos3, const QPointF& globalPos4, qreal value5, quint64 sequenceId6, quint64 intArgument7);
    QNativeGestureEvent_shell(Qt::NativeGestureType type0, const QPointingDevice* dev1, int fingerCount2, const QPointF& localPos3, const QPointF& scenePos4, const QPointF& globalPos5, qreal value6, const QPointF& delta7, quint64 sequenceId8 = UINT64_MAX);
    ~QNativeGestureEvent_shell() override;

    QNativeGestureEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNativeGestureEvent_access : public QNativeGestureEvent
{
    void __qt_assign_cref_QNativeGestureEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setRealValue_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble realValue0);
    jdouble realValue(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setSequenceId_quint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong sequenceId0);
    jlong sequenceId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QNATIVEGESTUREEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QNativeGestureEvent_shell.h <==
#ifndef QNATIVEGESTUREEVENT_SHELL_H
#define QNATIVEGESTUREEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QNativeGestureEvent_shell : public QNativeGestureEvent, public QtJambiShellInterface
{
public:
    QNativeGestureEvent_shell(const QNativeGestureEvent& arg__1);
    QNativeGestureEvent_shell(Qt::NativeGestureType type0, const QPointingDevice* dev1, const QPointF& localPos2, const QPointF& scenePos3, const QPointF& globalPos4, qreal value5, quint64 sequenceId6, quint64 intArgument7);
    QNativeGestureEvent_shell(Qt::NativeGestureType type0, const QPointingDevice* dev1, int fingerCount2, const QPointF& localPos3, const QPointF& scenePos4, const QPointF& globalPos5, qreal value6, const QPointF& delta7, quint64 sequenceId8 = UINT64_MAX);
    ~QNativeGestureEvent_shell() override;

    QNativeGestureEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNativeGestureEvent_access : public QNativeGestureEvent
{
    void __qt_assign_cref_QNativeGestureEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setRealValue_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble realValue0);
    jdouble realValue(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setSequenceId_quint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong sequenceId0);
    jlong sequenceId(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QNATIVEGESTUREEVENT_SHELL_H
